/*******************************************************************************
* File Name: main.h
*
* Version: 3.0
*
* Description:
*  This file provides the function prototypes, constants and macros for the
*  USBFS bootloadable example project.
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation. All rights reserved.
* This software is owned by Cypress Semiconductor Corporation and is protected
* by and subject to worldwide patent and copyright laws and treaties.
* Therefore, you may use this software only as provided in the license agreement
* accompanying the software package from which you obtained this software.
* CYPRESS AND ITS SUPPLIERS MAKE NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
* WITH REGARD TO THIS SOFTWARE, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT,
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
*******************************************************************************/

#if !defined(CY_MAIN_H)
#define CY_MAIN_H
#include <project.h>

/***************************************
*               Macros
****************************************/
void start_PWM(void);
 uint16 counterval;


    
//-----------------------------------------------------------
typedef  unsigned char  BOOL;
typedef  unsigned char  BYTE;
typedef  signed   char  CHAR;
typedef  unsigned int   WORD;
typedef  signed   int   INT;
typedef  unsigned long  DWORD;
typedef  signed   long  LONG;

//-----------------------------------------------
// Define Boolean TRUE/FALSE
//-----------------------------------------------
#define  TRUE  ((BOOL) 1)
#define  FALSE ((BOOL) 0)

#define BUFFER_SIZE   (64u)
BYTE	ReceiveData[BUFFER_SIZE];
BYTE	TransmittData[64];
#define Buffin_cmd		ReceiveData[0]	
#define Buffin_value	ReceiveData[1]
//------------------------------------------------
#define USBFS_DEVICE        (0u)

#define MOUSE_ENDPOINT      (1u)
#define MOUSE_DATA_LEN      (3u)
#define CURSOR_STEP         (5u)
#define CURSOR_STEP_POS     (1u)

#define NOERROR				0x00 	//	pas d'erreur
#define BUFFIN_CMD_ERROR	0xFF	// cmde non valable
/* Mouse packet array: button, X, Y */
uint8 mouseData[MOUSE_DATA_LEN] = {0u, 0u, 0u};
uint8 bSNstring[16u] = {0x0Eu, 0x03u, 'F', 0u, 'W', 0u, 'S', 0u, 'N', 0u, '0', 0u, '1', 0u};

/* USB device number. */
#define USBFS_DEVICE  (0u)
#define val         a
#define Buffin_cmd		ReceiveData[0]
/* Active endpoints of USB device. */
#define IN_EP_NUM     (1u)
#define OUT_EP_NUM    (2u)

#define test_T              101


/* Size of SRAM buffer to store endpoint data. */
#define BUFFER_SIZE   (64u)
BYTE	ReceiveData[BUFFER_SIZE];
BYTE	TransmittData[64];
#if (USBFS_16BITS_EP_ACCESS_ENABLE)
    /* To use the 16-bit APIs, the buffer has to be:
    *  1. The buffer size must be multiple of 2 (when endpoint size is odd).
    *     For example: the endpoint size is 63, the buffer size must be 64.
    *  2. The buffer has to be aligned to 2 bytes boundary to not cause exception
    *     while 16-bit access.
    */
    #ifdef CY_ALIGN
        /* Compiler supports alignment attribute: __ARMCC_VERSION and __GNUC__ */
        CY_ALIGN(2) uint8 buffer[BUFFER_SIZE];
    #else
        /* Complier uses pragma for alignment: __ICCARM__ */
        #pragma data_alignment = 2
        uint8 buffer[BUFFER_SIZE];
    #endif /* (CY_ALIGN) */
#else
    /* There are no specific requirements to the buffer size and alignment for 
    * the 8-bit APIs usage.
    */
    uint8 buffer[BUFFER_SIZE];
#endif /* (USBFS_GEN_16BITS_EP_ACCESS) */


#define LIGHT_OFF                       (0u)
#define LIGHT_ON                        (1u)
#define A "test1"
#define B "test2"
#define BUFF_VAL1     0xAC
#define BUFF_VAL2     0xDD

#define LVTHRESHOLD  40                 /* 16V */
#define HVTHRESHOLD  90                /* 36V */  
	
#define LVCNTTHRES  2560                 
#define HVCNTTHRES  2560                

/* ADC channel number for speed reference potentiometer */     
#define SPEED_REF_CHAN                      ((uint8)(1))     
/* ADC result range */    
#define ADC_RANGE                           ((uint16)(4096))      
/* define the maximum resistor value for potentiometer */    
#define SPEED_POT_VALUE                     (uint16)(10000)    
/* define the accepted maximum/minimum value for the sample result of speed reference potentiometer,
   minus 100 to reduce the offset at the boundary*/    
#define MAX_SPEED_REF_ADC_VALUE             (uint16)((((SPEED_POT_VALUE + 330) * ADC_RANGE)/(SPEED_POT_VALUE + 330 + 330)) - 30)    
#define MIN_SPEED_REF_ADC_VALUE             (uint16)((((330) * ADC_RANGE)/(SPEED_POT_VALUE + 330 + 330)) + 30)        

void VoltageCheck(void);
uint16 ReadRpmRef(void);

extern uint16 dutyCycle;                           /* duty cycle value applied on driving PWM */
extern uint16 speedRefCount;                       /* given speed reference */
extern uint16 speedCurCount;                       /* measured rotation speed */
extern uint8  needRunSpeedPID;                     /* flag to sync with PWM ticker ISR to run speed PID */
extern uint8  needUpdateSpeedRef;                  /* flag to sync with PWM ticker ISR to update speed reference */

/******************************************************************************
 * Structure/Enum type declaration   
 ******************************************************************************/   
/* enum type for error code */
typedef enum _Error_Code
{
    NO_ERROR,                               /* no error happens */
    ZC_CHECK_ERROR,                         /* zero-crossing detection failure */
    OV_ERROR,                               /* over voltage happens */
    UV_ERROR,                               /* under voltage happens */
    FREERUN_ERROR,                          /* freerun stage fails, fail to enter close loop */ 
    ANY_ERROR,                              /* for any unknown error */
    ERROR_SIZE                              /* varialbe to store count of error types */
}Error_Code_T;

/* Structure type to store control varialbe during BLDC roration */
typedef struct _Run_Control
{
    uint8           runFlag;                /* flag to start motor running */
    Error_Code_T    errorCode;              /* error code for motor running */
    
    uint8           sector;                 /* one of 6 sector of BLDC control */ 
    uint8           checkFallingEdge;       /* If check fall edge of BEMF */ 
	uint8           inNormalRun;            /* flag to indicate if motor works in normal run stage*/ 
    
    uint16          speedMeasuredRpm;       /* speed measured by counter, in RPM uint */
    uint16          speedRefRpm;            /* current speed reference, may be smaller than speedGivenRpm */
    uint16          speedGivenRpm;          /* given speed reference which is desired to achevie  */
    
    uint16          commutateStamp;         /* Time stamp of latest commucation event */
    uint16          zeroCrossStamp;         /* Previoius Time stamp of previous commucation event */ 
    uint16          zeroCrossPeriod;        /* Period between two commucation event */ 
	uint16          delayTime;	            /* Delay time between zero-cross and commutation */ 
    
    int32           pidOutput;              /* PID output */
    int32           pidSpeedErr;            /* speed count error in speed PID */
}BLDC_Control_T;

/* enum type for BLDC running state */
typedef enum
{
    STOPPED         = 0x01 ,                /* motor stop state */
    FREERUNNING     = 0x02 ,                /* freerun state, open loop during motor startup */
    NORMALRUN       = 0x03 ,                /* normal run state with sesorless control after BEMF is detected */
    ERRORSTOP       = 0x04 ,                /* error state if error happens in normal run  */
    FREERUNFAILED   = 0x05 ,                /* error state if freerun stage failed */
    PREPOSITION     = 0x06 ,                /* error state if freerun stage failed */
    OCERROR         = 0x07 ,                /* error state if over current happens */
} Motor_Stage_T;

/* enum type for rotation direction */
typedef enum _Direction
{
	CLOCK,                                /* clock rotation direction */
	COUNTER_CLOCK                         /* counter-clock rotation direction */
}Direction_T;

typedef struct _BLDC_Config
{   
    /*-----------------------------------------------------------------------------*
     * motor parameters                                                            *
     *-----------------------------------------------------------------------------*/
    uint8   polePairNumber;              /* motor pole-pair number */ 
    
    /*-----------------------------------------------------------------------------*
     * general parameters                                                          *
     *-----------------------------------------------------------------------------*/
    Direction_T   direction;             /* rotation direction */    
    uint16  initSpeedRefRpm;             /* initial speed reference, in RPM uint */    
   
    /*-----------------------------------------------------------------------------*
     * PID parameters                                                              *
     *-----------------------------------------------------------------------------*/
    uint32  kp;                          /* coefficient of PI partial portion */   
    uint32  ki;                          /* coefficient of PI integration portion */
    
    /*-----------------------------------------------------------------------------*
     * preposition parameters                                                      *
     *-----------------------------------------------------------------------------*/
    uint16  prepositionTime;             /* time for preposition stage */
    uint16  prepositionDuty;             /* dutycycle for preposition stage */
    
    /*-----------------------------------------------------------------------------*
     * startup parameters                                                          *
     *-----------------------------------------------------------------------------*/
    uint16  startDuty;                   /* duty cycle to start roration from stop */
    uint16  freerunDuty;                 /* duty cycle for free run (open loop mode) */
    uint16  startCheckPeriod;            /* timeout period for every startup zero 
                                            crossing checking */
    uint8   startStageWait;              /* wait count for staying in start stage */
    uint8   decStageInterval;            /* interval between two decreasing for duty
                                            cycle in decreasing stage */
    uint8   freerunStageWait;            /* wait count for staying in free run stage */
    uint8   accStageInterval;            /* interval between two increasing for duty 
                                            cycle in increasing stage */
    uint8   accStageWait;                /* execution times for acceleration stage */
    uint8   accDutyStep;                 /* increase step for duty cycle in 
                                            accelaration stage */
    uint8   accTimeStep;                 /* decrease step for checking period in 
                                            accelaration stage */
    
    /*-----------------------------------------------------------------------------*
     * normal run parameters                                                       *
     *-----------------------------------------------------------------------------*/
    uint8   speedCloseLoopWait;          /* wait count in speed open loop mode before 
                                            switching to speed close loop mode */
    uint8   zcCheckSkipCount;            /* the count for skipping zero crossing 
                                            checking during flywheel pulse */
}BLDC_Config_T;
/******************************************************************************
 * Global variables declaration   
 ******************************************************************************/    
extern BLDC_Control_T   BLDC_Control;              /* Structure varialbe for control BLDC running */
extern BLDC_Config_T    BLDC_Config;               /* Structure varialbe to store motor parameter */
extern Motor_Stage_T   runState;                   /* enum variable to store running state */

//***********************************************************|
//                                                           |
//                      param_moteur                         |                                               
//                                                           |
//                                                           |
/************************************************************/
/*============================================================================   
 * macro for motor physical parameters
 *============================================================================*/      
/* motor pole-pairs number */
#define MOTOR_POLE_PAIR_NUM                 ((uint8)(4))     
/*============================================================================   
 * macro for solution general setting
 *============================================================================*/   
/* VDD range */
#define VDD_RANGE                           ((uint8)(5))  
/* resistor divider scale for DC bus voltage */
#define DC_BUS_SAMPLE_SCALE                 ((uint8)((1+19.1)/1))    
/* PMW frequency, uint: Hz */
#define PMW_FREQ                            ((uint16)(20000))    
/* PWM period */
#define PWM_PERIOD                          ((uint16)(1200))   
/* clock frequency for speed measurement */
#define SPEED_MEASURE_CLOCK_FREQ            ((uint32)(320 * 1000))                              /* 300KHz */    
/* seconds per minutes */
#define SECOND_PER_MINUTE                   ((uint8)(60))    
/* operation voltage for DC bus, uint: V */
#define NORMAL_DC_VOLTAGE                   ((uint8)(24))      
/* ADC result range */    
#define ADC_RANGE                           ((uint16)(4096))        
/*============================================================================   
 * macro for ADC sampling
 *============================================================================*/   
/* ADC channel number for DC bus voltage sample */    
#define DC_BUS_CHAN                         ((uint8)(0))
/* ADC channel number for speed reference potentiometer */     
#define SPEED_REF_CHAN                      ((uint8)(1)) 
/* define the maximum resistor value for potentiometer */    
#define SPEED_POT_VALUE                     (uint16)(10000)
/* define the accepted maximum/minimum value for the sample result of speed reference potentiometer,
   minus 100 to reduce the offset at the boundary*/    
#define MAX_SPEED_REF_ADC_VALUE             (uint16)((((SPEED_POT_VALUE + 330) * ADC_RANGE)/(SPEED_POT_VALUE + 330 + 330)) - 30)    
#define MIN_SPEED_REF_ADC_VALUE             (uint16)((((330) * ADC_RANGE)/(SPEED_POT_VALUE + 330 + 330)) + 30)    
/*============================================================================   
 * macro for speed PID control
 *============================================================================*/   
/* default value for kp */
#define KP_INITIAL_VALUE                    ((uint32)(140000))
/* default value for ki */
#define KI_INITIAL_VALUE                    ((uint32)(8000))        
/* maximum duty cycle for driving PWM */    
#define MAX_PWM_DUTY                        ((uint16)(PWM_PERIOD * 1000 / 1000))                 /* 100% */
/* minimum duty cycle for driving PWM */    
#define MIN_PWM_DUTY                        ((uint16)(PWM_PERIOD * 90 / 1000))                   /* 9% */
/* speed threshold to change the Kp and Ki */
#define SWITCH_SPEED_RPM                    ((uint16)(2000))                                    /* RPM uint */ 
/* period time for executing speed PID control */
#define SPEED_PID_EXEC_INTERVAL             ((uint16)(10 * PMW_FREQ / 1000))                    /* 10ms */
/* period time for updating speed reference */
#define SPEED_REF_UPDATE_INTERVAL             ((uint16)(10 * PMW_FREQ / 1000))                  /* 10ms */    
/*============================================================================   
 * macro for preposition
 *============================================================================*/   
/* duty cycle for preposition stage */
#define PREPOSITION_PWM_DUTY                MIN_PWM_DUTY    
/* wait time for preposition stage */
#define PREPOSITION_WAIT_TIME               ((uint16)(10000))       
/*============================================================================   
 * macro for startup
 *============================================================================*/       
/* default initial start duty cycle to make rotor rotate */
#define START_PWM_DUTY                      ((uint16)(PWM_PERIOD * 300 / 1000))                 /* 30.0% */              
/* default duty cycle for free run in open loop */
#define FREERUN_PWM_DUTY                    ((uint16)(PWM_PERIOD * 208 / 1000))                 /* 20.8% */  
/* default timeout time for every startup zero crosing checking */
#define START_ZC_CHECK_PERIOD               ((uint16)(4 * SPEED_MEASURE_CLOCK_FREQ / 1000))     /*  4ms */  
/* default wait count for staying in start stage of startup */   
#define START_STAGE_WAIT_COUNT              ((uint8)(10))    
/* default interval between two duty cycle decreasing for decreasing stage of startup */
#define DEC_STAGE_INTERVAL                  ((uint8)(1))
/* default wait count for staying in free run stage of startup */
#define FREERUN_STAGE_WAIT_COUNT            ((uint8)(10)) 
/* default interval between two duty cycle increasing for increasing stage of startup */
#define ACC_STAGE_INTERVAL                  ((uint8)(10))  
/* default execution times for acceleration stage */    
#define ACC_STAGE_EXEC_COUNT                ((uint8)(200))  
    
/* timeout period increase step for acceleration state */
#define ACC_STAGE_TIME_STEP                 ((uint8)(40))    
/* duty cycle increase step for acceleration state */    
#define ACC_STAGE_DUTY_STEP                 ((uint8)(0))     
/* zero crossing count to switch to normal run state */    
#define ZC_CHECKING_STABLE_THRESHOLD        (uint8)(3)
/* threshold to reset zero crossing counter to remove accumulate error */
#define ZC_COUNT_RESET_THRESHOLD            (uint8)(10)    
/*============================================================================   
 * macro for speed reference
 *============================================================================*/     
/* initial speed reference after motor enter into close loop */
#define INIT_SPEED_REF_RPM                  ((uint16)(1000))                                    /* uint: RPM */  
/* maximum speed reference for motor running */    
#define MAX_SPEED_REF_RPM                   ((uint16)(4000))                                    /* uint: RPM */
/* minimum speed reference for motor running */    
#define MIN_SPEED_REF_RPM                   ((uint16)(500))                                     /* uint: RPM */
/* maximum step for speed reference update */
#define MAX_SPEED_REF_UPDATE_STEP           ((uint16)400)  
/*============================================================================   
 * macro for protection
 *============================================================================*/
/* ADC sample result for normal operation voltage of DC BUS */ 
#define DC_BUS_SAMPLE_VALUE                 ((uint16)(((ADC_RANGE * NORMAL_DC_VOLTAGE) / (DC_BUS_SAMPLE_SCALE * VDD_RANGE)) & 0x0FFF))   
/* deboundce checking count threshold for voltage checking */
#define PROTECTION_DEBOUNDCE_CNT            ((uint8)(10))
    
#define  MAX_CURR_LOW                       ((uint8)50)       /*1A*/
#define  MAX_CURR_MEDIUM                    ((uint8)75)       /*1.5A*/
#define  MAX_CURR_HIGH                      ((uint8)100)      /*2A*/        
/*============================================================================   
 * macro for error detection
 *============================================================================*/
/* threshold to trigger zero crossing check failure error */
#define ZC_CHECK_ERROR_THRESHOLD            ((uint16)(80 * SPEED_MEASURE_CLOCK_FREQ / 1000))    /* 80ms */

#define PI_RANGE_SCALE                      (uint8)(20)    
#define LIMIT_MAX                           ((int32)(((MAX_PWM_DUTY - MIN_PWM_DUTY)/2) * (1 << PI_RANGE_SCALE)))
#define LIMIT_MIN                           ((int32)(-(LIMIT_MAX)))      
#define LIMIT_HALF_RANGE                    ((int32)(((MAX_PWM_DUTY + MIN_PWM_DUTY)/2) * (1 << PI_RANGE_SCALE)))   
    
/* scaler to adjust the range of Kp in PID control */
#define PID_KP_SCALER                       (uint8)(1)
/* scaler to adjust the range of Ki in PID control */
#define PID_KI_SCALER                       (uint8)(1)   

//                                                                                                                            |
#ifndef TRUE
    #define TRUE 1
#endif
#ifndef FALSE
    #define FALSE 0
#endif

/* Define to store the Frequency of the Clock used for the Counter(TCPWM component).
 * The value is defined in Hz */
#define CLOCK_FREQ (float)3000000

/* Define to indicate the number of microseconds in 1 second. Used for scaling purpose */
#define NO_OF_USEC 1000000u

/* Variable to store the number of times the Counter has overflown */
uint32 counter_overflowCount = 0u;

/* Variable to indicate the occurrence of the Capture Interrupt. The Counter generates interrupt on the
 * Terminal count and / or on the Capture event. The flag is set inside the Capture interrupt and cleared in the
 * main.c after processing */
uint8 CC_ISR_flag = FALSE;

/* Variable to store the count value that is captured at the instance of the rising edge of the
 * capture signal */
uint16 capturedCount = 0u;                                                                                      
/*****************************************************************************************************************************/
//-----------------------------------------------
//          variable adc                        |
//                                              |
//-----------------------------------------------
#define CHANNEL_1           (0u)
#define CHANNEL_2           (1u)
#define CHANNEL_3           (2u)
#define CHANNEL_4           (3u)
#define NO_OF_CHANNELS      (4u)
#define CLEAR_SCREEN        (0x0C)
#define CONVERT_TO_ASCII    (0x30u)

/* Resistor Values and Gain */
#define RG                  (2200u)
#define R1                  (10000u)
#define GAIN                (1 + 2 * (float)R1 / RG)
//                                                   |




#endif /* (CY_MAIN_H) */


/* [] END OF FILE */
